summaryrefslogtreecommitdiffstats
path: root/src/sysext
diff options
context:
space:
mode:
authorYu Watanabe <watanabe.yu+github@gmail.com>2021-01-30 17:12:27 +0100
committerYu Watanabe <watanabe.yu+github@gmail.com>2021-02-09 06:25:03 +0100
commit8087644a134cd1ed52e81d41ee27d54c3bb7ad65 (patch)
treee83422bf1ac34ebdfa45bed99d42bb796513be1a /src/sysext
parentstring-util: introduce strverscmp_improved() (diff)
downloadsystemd-8087644a134cd1ed52e81d41ee27d54c3bb7ad65.tar.xz
systemd-8087644a134cd1ed52e81d41ee27d54c3bb7ad65.zip
tree-wide: replace strverscmp() and str_verscmp() with strverscmp_improved()
Diffstat (limited to 'src/sysext')
-rw-r--r--src/sysext/sysext.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/sysext/sysext.c b/src/sysext/sysext.c
index a17f4e2c02..1ce9939afb 100644
--- a/src/sysext/sysext.c
+++ b/src/sysext/sysext.c
@@ -395,9 +395,9 @@ static int merge_hierarchy(
return 1;
}
-static int strverscmpp(char *const* a, char *const* b) {
- /* usable in qsort() for sorting a string array with strverscmp() */
- return strverscmp(*a, *b);
+static int strverscmp_improvedp(char *const* a, char *const* b) {
+ /* usable in qsort() for sorting a string array with strverscmp_improved() */
+ return strverscmp_improved(*a, *b);
}
static int validate_version(
@@ -623,8 +623,8 @@ static int merge_subprocess(Hashmap *images, const char *workspace) {
return 0;
}
- /* Order by version sort (i.e. libc strverscmp()) */
- typesafe_qsort(extensions, n_extensions, strverscmpp);
+ /* Order by version sort with strverscmp_improved() */
+ typesafe_qsort(extensions, n_extensions, strverscmp_improvedp);
buf = strv_join(extensions, "', '");
if (!buf)